Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: components/security_state/security_state_model.h

Issue 2494033002: Revert "HTTP Bad: Split out UMA metrics for password vs credit card "Not secure" warnings" (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/security_state/security_state_model.h
diff --git a/components/security_state/security_state_model.h b/components/security_state/security_state_model.h
index b740bb1058c8ab3e098080fd754920f136f510b7..235c6b5e224211fe15b3e8b59c893d6fda2f05e4 100644
--- a/components/security_state/security_state_model.h
+++ b/components/security_state/security_state_model.h
@@ -137,11 +137,9 @@ class SecurityStateModel {
// True if pinning was bypassed due to a local trust anchor.
bool pkp_bypassed;
- // True if the page displayed password field on an HTTP page.
- bool displayed_password_field_on_http;
-
- // True if the page displayed credit card field on an HTTP page.
- bool displayed_credit_card_field_on_http;
+ // True if the page displayed sensitive user data inputs (like a
+ // password or credit card) on an HTTP page.
+ bool displayed_private_user_data_input_on_http;
};
// Contains the security state relevant to computing the SecurityInfo
« no previous file with comments | « chrome/browser/ssl/chrome_security_state_model_client_unittest.cc ('k') | components/security_state/security_state_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698